from __future__ import annotations

import akasha


async def test_leaderboard() -> None:
    async with akasha.AkashaAPI() as api:
        async for board in api.get_leaderboards(1000000203, max_page=1):
            assert board.uid


async def test_leaderboard_for_uid() -> None:
    async with akasha.AkashaAPI() as api:
        data = await api.get_leaderboard_for_uid(1000009808, uid=901211014)
        assert data and data.uid == "901211014"


async def test_leaderboard_total_size() -> None:
    async with akasha.AkashaAPI() as api:
        await api.get_leaderboard_total_size(1000009808)



from __future__ import annotations

import akasha


async def test_user_calc() -> None:
    async with akasha.AkashaAPI() as api:
        await api.get_calculations_for_user(901211014)


async def test_non_existent_user() -> None:
    async with akasha.AkashaAPI() as api:
        await api.get_calculations_for_user(0)



from __future__ import annotations

import akasha


async def test_multi_translate() -> None:
    for lang in akasha.Language:
        if lang is akasha.Language.ENGLISH:
            continue
        async with akasha.AkashaAPI(lang) as api:
            await api.get_translations(["Kamisato Ayaka", "Mistsplitter Reforged"])


async def test_single_translate() -> None:
    for lang in akasha.Language:
        if lang is akasha.Language.ENGLISH:
            continue
        async with akasha.AkashaAPI(lang) as api:
            await api.translate("Kamisato Ayaka")



from __future__ import annotations

import akasha


async def test_get_artifact() -> None:
    async with akasha.AkashaAPI() as api:
        await api.get_artifacts(820863575, "69313a2a03491ee368aa75837d1da7af")
